pub struct StorageKey<'a>(pub &'a [u8]);Expand description
A wrapper for bytes slice which tries to guess best way to format it.
If the slice is exactly 32-byte long, it’s assumed to be a hash and is
converted into base58 and printed surrounded by backtics. Otherwise,
behaves like Bytes representing the data as string if it contains ASCII
printable bytes only or base64 otherwise.
The motivation for such choices is that we only ever use base58 to format hashes which are 32-byte long. It’s therefore not useful to use it for any other types of keys.
The intended usage for this type is when trying to format binary data whose structure isn’t known to the caller. For example, when generating debugging or tracing data at database layer where everything is just slices of bytes. At higher levels of abstractions, if the structure of the data is known, it’s usually better to format data in a way that makes sense for the given type.
The type can be used as with tracing::info! and similar calls. For
example:
tracing::info!(target: "store",
op = "set",
col = %col,
key = %unc_fmt::StorageKey(key),
size = value.len())Tuple Fields
0: &'a [u8]