pub struct AbbrBytes<T>(pub T);Expand description
A wrapper for bytes slice which tries to guess best way to format it truncating the value if it’s too long.
Behaves like Bytes but truncates the formatted string to around 128
characters. If the value is longer then that, the length of the value in
bytes is included at the beginning and ellipsis is included at the end of
the value.
Tuple Fields
0: TTrait Implementations