pub struct Slice<'a, T>(pub &'a [T]);Expand description
A wrapper for slices which formats the slice limiting the length.
If the slice has no more than five elements, it’s printed in full. Otherwise, only the first two and last two elements are printed to limit the length of the formatted value.
Tuple Fields
0: &'a [T]Trait Implementations